@@ -36,12 +36,14 @@
 #include <goffice/graph/gog-renderer.h>
 #include <goffice/utils/go-format.h>
 #include <goffice/utils/go-math.h>
-#include <goffice/gtk/goffice-gtk.h>
-#include <goffice/gtk/go-format-sel.h>
+#include <goffice/data/go-data-simple.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
 
+#ifdef GOFFICE_WITH_GTK
+#include <goffice/gtk/goffice-gtk.h>
+#include <goffice/gtk/go-format-sel.h>
 #include <gtk/gtkcellrenderertext.h>
 #include <gtk/gtkcelllayout.h>
 #include <gtk/gtkcheckbutton.h>
@@ -51,13 +53,35 @@
 #include <gtk/gtkmisc.h>
 #include <gtk/gtknotebook.h>
 #include <gtk/gtktable.h>
+#include <gtk/gtkspinbutton.h>
 #include <gtk/gtktogglebutton.h>
+#endif
 
 #include <string.h>
 
 /* this should be per model */
 #define PAD_HACK	4	/* pts */
 
+static struct {
+	GogAxisPolarUnit unit;
+	const char 	*name;
+	double		 perimeter;
+	const char	*xl_format;
+	double		 auto_minimum;
+	double		 auto_maximum;
+	double		 auto_major;
+	double		 auto_minor;	
+} polar_units[GOG_AXIS_POLAR_UNIT_MAX] = {
+	{ GOG_AXIS_POLAR_UNIT_DEGREES, N_("Degrees"), 360.0,	"0\"°\"",   0.0, 360.0,     30.0,      10.0},
+	{ GOG_AXIS_POLAR_UNIT_RADIANS, N_("Radians"), 2 * M_PI,	"?pi/??", -M_PI,  M_PI, M_PI/4.0, M_PI/16.0},
+	{ GOG_AXIS_POLAR_UNIT_GRADS,   N_("Grads"),   400.0,	"General",  0.0, 400.0,     50.0,      10.0}
+};
+
+#define GOG_AXIS_CIRCULAR_ROTATION_MIN -180.0
+#define GOG_AXIS_CIRCULAR_ROTATION_MAX  180.0
+
+typedef struct _GogAxisMapDesc GogAxisMapDesc;
+
 struct _GogAxis {
 	GogAxisBase	 base;
 
@@ -79,6 +103,9 @@ struct _GogAxis {
 
 	GogAxisMapDesc const 	*map_desc;
 
+	GogAxisPolarUnit	 polar_unit;
+	double			 circular_rotation;
+
 	GogAxisTick	*ticks;
 	unsigned	 tick_nbr;
 };
@@ -94,26 +121,6 @@ struct _GogAxis {
 
 static void gog_axis_set_ticks (GogAxis *axis,int tick_nbr, GogAxisTick *ticks);
 
-static GogAxisTick *
-get_adjusted_tick_array (GogAxisTick *ticks, int allocated_size, int exact_size) 
-{
-	GogAxisTick *tmp_ticks;
-	
-	if (exact_size > 0) {
-		if (exact_size != allocated_size) {
-			tmp_ticks = g_new (GogAxisTick, exact_size);
-			memcpy (tmp_ticks, ticks, sizeof (GogAxisTick) * exact_size);
-			g_free (ticks);
-		} else
-			tmp_ticks = ticks;
-	} else {
-		g_free (ticks);
-		tmp_ticks = NULL;
-	}
-
-	return tmp_ticks;
-}
-
 static GogAxisTick *
 create_invalid_axis_ticks (double min, double max) 
 {
@@ -129,6 +136,32 @@ create_invalid_axis_ticks (double min, double max)
 	return ticks;
 }
 
+/*****************************************************************************/
+
+struct _GogAxisMap {
+	GogAxis		*axis;
+	GogAxisMapDesc	const *desc;
+	gpointer	 data;
+	gboolean	 is_valid;	/* Default to FALSE if desc::init == NULL */
+};
+
+struct _GogAxisMapDesc {
+	double 		(*map) 		 (GogAxisMap *map, double value);
+	double 		(*map_to_view)   (GogAxisMap *map, double value);
+	double 		(*map_from_view) (GogAxisMap *map, double value);
+	gboolean	(*map_finite)    (double value);
+	double		(*map_baseline)  (GogAxisMap *map);
+	void		(*map_bounds)	 (GogAxisMap *map, double *minimum, double *maximum);
+	gboolean 	(*init) 	 (GogAxisMap *map, double offset, double length);
+	void		(*destroy) 	 (GogAxisMap *map);
+	void		(*auto_bound) 	 (GogAxis *axis, 
+					  double minimum, double maximum,
+					  double *bound);
+	void		(*calc_ticks) 	 (GogAxis *axis);
+	char const	*name;
+	char const	*description;
+};
+
 /*
  * Discrete mapping
  */
@@ -201,7 +234,7 @@ map_discrete_auto_bound (GogAxis *axis,
 	if ((maximum - minimum) > GOG_AXIS_DISCRETE_AUTO_MAX_MAJOR_TICK_NBR) 
 		bound [GOG_AXIS_ELEM_MAJOR_TICK] = 
 		bound [GOG_AXIS_ELEM_MINOR_TICK] =
-			ceil ((maximum - minimum + 1.0) / 
+			go_fake_ceil ((maximum - minimum + 1.0) / 
 			      (double) GOG_AXIS_DISCRETE_AUTO_MAX_MAJOR_TICK_NBR); 
 	else
 		bound [GOG_AXIS_ELEM_MAJOR_TICK] = 
@@ -236,11 +269,11 @@ map_discrete_calc_ticks (GogAxis *axis)
 	}
 		
 	tick_start = axis->center_on_ticks ? 
-		ceil (minimum / (double) major_tick) * major_tick : 
-		ceil ((minimum - 0.5) / (double) major_tick) * major_tick + 0.5;
-	label_start = ceil (minimum / (double) major_label) * major_label;
-	tick_nbr = floor (go_add_epsilon (maximum - tick_start) / major_tick + 1.0);
-	label_nbr = floor (go_add_epsilon (maximum - label_start) / major_label + 1.0);
+		go_fake_ceil (minimum / (double) major_tick) * major_tick : 
+		go_fake_ceil ((minimum - 0.5) / (double) major_tick) * major_tick + 0.5;
+	label_start = go_fake_ceil (minimum / (double) major_label) * major_label;
+	tick_nbr = go_fake_floor ((maximum - tick_start) / major_tick + 1.0);
+	label_nbr = go_fake_floor ((maximum - label_start) / major_label + 1.0);
 	tick_nbr = CLAMP (tick_nbr, 0, GOG_AXIS_MAX_TICK_NBR);
 	label_nbr = CLAMP (label_nbr, 0, GOG_AXIS_MAX_TICK_NBR);
 	if (tick_nbr < 1  && label_nbr < 1) {
@@ -259,9 +292,11 @@ map_discrete_calc_ticks (GogAxis *axis)
 		index = ticks[j].position - 1;
 		ticks[j].type = GOG_AXIS_TICK_NONE;
 		if (axis->labels != NULL) {
-			if (index < go_data_vector_get_len (axis->labels) && index >= 0)
-				ticks[j].label = go_data_vector_get_str (axis->labels, index);
-			else
+			if (index < go_data_vector_get_len (axis->labels) && index >= 0) {
+				char *label = go_data_vector_get_str (axis->labels, index);
+				ticks[j].label = g_markup_escape_text (label, -1);
+				g_free (label);
+			} else
 				ticks[j].label = NULL;
 		}
 		else
@@ -354,10 +389,10 @@ map_linear_auto_bound (GogAxis *axis, double minimum, double maximum, double *bo
 	int expon;
 
 	if (gog_axis_get_atype (axis) == GOG_AXIS_CIRCULAR) {
-		bound[GOG_AXIS_ELEM_MIN] = 0.0;
-		bound[GOG_AXIS_ELEM_MAX] = 360.0;
-		bound[GOG_AXIS_ELEM_MAJOR_TICK] = 30.0;
-		bound[GOG_AXIS_ELEM_MINOR_TICK] = 10.0;
+		bound[GOG_AXIS_ELEM_MIN] = polar_units[axis->polar_unit].auto_minimum;
+		bound[GOG_AXIS_ELEM_MAX] = polar_units[axis->polar_unit].auto_maximum;
+		bound[GOG_AXIS_ELEM_MAJOR_TICK] = polar_units[axis->polar_unit].auto_major;
+		bound[GOG_AXIS_ELEM_MINOR_TICK] = polar_units[axis->polar_unit].auto_minor;
 		return;
 	}	
 
@@ -428,13 +463,13 @@ map_linear_calc_ticks (GogAxis *axis)
 	if (major_tick <= 0.) major_tick = maximum - minimum;
 	if (minor_tick <= 0.) minor_tick = maximum - minimum;
 	if (minor_tick < major_tick) {
-		minor_tick = major_tick / rint (major_tick / minor_tick);
+		minor_tick = major_tick / go_rint (major_tick / minor_tick);
 		tick_step = minor_tick;
 	} else
 		tick_step = major_tick;
 	
-	start = ceil (minimum / tick_step) * tick_step;
-	tick_nbr = floor (go_add_epsilon ((maximum - start) / tick_step + 1.0));
+	start = go_fake_ceil (minimum / tick_step) * tick_step;
+	tick_nbr = go_fake_floor ((maximum - start) / tick_step + 1.0);
 	if (tick_nbr < 1 || tick_nbr > GOG_AXIS_MAX_TICK_NBR) {
 		gog_axis_set_ticks (axis, 0, NULL);
 		return;
@@ -443,17 +478,19 @@ map_linear_calc_ticks (GogAxis *axis)
 
 	for (i = 0; i < tick_nbr; i++) {
 		ticks[i].position = start + (double) i * tick_step;
-		if (fabs (ticks[i].position) < tick_step / 1E10)
+		if (fabs (ticks[i].position) < tick_step * 1e-10)
 			ticks[i].position = 0.0;
 		ratio = ticks[i].position / major_tick;
-		if (fabs (ratio - rint (ratio)) < 1E-3) {
+		if (fabs (ratio - go_rint (ratio)) < 1E-3) {
 			ticks[i].type = GOG_AXIS_TICK_MAJOR;
-				if (axis->assigned_format == NULL || 
-				    go_format_is_general (axis->assigned_format))
-					ticks[i].label = go_format_value (axis->format, ticks[i].position);
-				else
-					ticks[i].label = go_format_value (axis->assigned_format, ticks[i].position);
-			}
+			if (axis->assigned_format == NULL || 
+			    go_format_is_general (axis->assigned_format))
+				ticks[i].label = go_format_value (axis->format, 
+								  ticks[i].position);
+			else
+				ticks[i].label = go_format_value (axis->assigned_format, 
+								  ticks[i].position);
+		}
 		else {
 			ticks[i].type = GOG_AXIS_TICK_MINOR;
 			ticks[i].label = NULL;
@@ -555,7 +592,7 @@ map_log_baseline (GogAxisMap *map)
 	MapLogData *data = map->data;
 
 	return map->axis->inverted ?
-		data->max * data->a_inv + data->b_inv :
+		data->min * data->a_inv + data->b_inv :
 		data->min * data->a + data->b;
 }
 
@@ -580,10 +617,10 @@ map_log_auto_bound (GogAxis *axis, double minimum, double maximum, double *bound
 	if (maximum < minimum)
 		maximum = minimum * 100.0;
 
-	maximum = ceil (log10 (maximum));
-	minimum = floor (log10 (minimum));
+	maximum = go_fake_ceil (log10 (maximum));
+	minimum = go_fake_floor (log10 (minimum));
 	
-	step = ceil ((maximum - minimum + 1.0) / 
+	step = go_fake_ceil ((maximum - minimum + 1.0) / 
 		     (double) GOG_AXIS_LOG_AUTO_MAX_MAJOR_TICK_NBR); 
 
 	bound [GOG_AXIS_ELEM_MIN] = pow ( 10.0, minimum);
@@ -602,8 +639,8 @@ map_log_calc_ticks (GogAxis *axis)
 	int tick_nbr, i, j;
 	int count;
 
-	major_label = rint (gog_axis_get_entry (axis, GOG_AXIS_ELEM_MAJOR_TICK, NULL));
-	minor_tick = rint (gog_axis_get_entry (axis, GOG_AXIS_ELEM_MINOR_TICK, NULL) + 1.0);
+	major_label = go_rint (gog_axis_get_entry (axis, GOG_AXIS_ELEM_MAJOR_TICK, NULL));
+	minor_tick = go_rint (gog_axis_get_entry (axis, GOG_AXIS_ELEM_MINOR_TICK, NULL) + 1.0);
 
 	if (!gog_axis_get_bounds (axis, &minimum, &maximum) || major_label < 1) {
 		gog_axis_set_ticks (axis, 2, create_invalid_axis_ticks (1.0, 10.0));
@@ -614,8 +651,9 @@ map_log_calc_ticks (GogAxis *axis)
 		return;
 	}
 
-	start_tick = ceil (log10 (minimum));
-	tick_nbr = major_tick = ceil (ceil (log10 (maximum)) - floor (log10 (minimum)) + 1.0);
+	start_tick = go_fake_floor (log10 (minimum));
+	tick_nbr = major_tick = go_fake_ceil (go_fake_ceil (log10 (maximum)) - 
+					      go_fake_floor (log10 (minimum)) + 1.0);
 	tick_nbr *= minor_tick;
 	if (tick_nbr < 1 || tick_nbr > GOG_AXIS_MAX_TICK_NBR) {
 		gog_axis_set_ticks (axis, 0, NULL);
@@ -632,9 +670,11 @@ map_log_calc_ticks (GogAxis *axis)
 				ticks[count].type = GOG_AXIS_TICK_MAJOR;
 				if (axis->assigned_format == NULL || 
 				    go_format_is_general (axis->assigned_format))
-					ticks[count].label = go_format_value (axis->format, ticks[count].position);
+					ticks[count].label = go_format_value (axis->format,
+									      ticks[count].position);
 				else
-					ticks[count].label = go_format_value (axis->assigned_format, ticks[count].position);
+					ticks[count].label = go_format_value (axis->assigned_format, 
+									      ticks[count].position);
 				count++;
 			}
 			else {
@@ -643,18 +683,21 @@ map_log_calc_ticks (GogAxis *axis)
 				count++;
 			}
 		} 
-			for (j = 1; j < minor_tick; j++) {
-				position = pow (10.0, i + start_tick) * (9.0 / (double)minor_tick * (double) j + 1.0);
-				if (position >= go_sub_epsilon (minimum) && go_sub_epsilon (position) <= maximum) {
-					ticks[count].position = position;
-					ticks[count].type = GOG_AXIS_TICK_MINOR;
-					ticks[count].label = NULL;
-					count++;
-				}
+		for (j = 1; j < minor_tick; j++) {
+			position = pow (10.0, i + start_tick) * (9.0 / (double)minor_tick * (double) j + 1.0);
+			if (position >= go_sub_epsilon (minimum) && go_sub_epsilon (position) <= maximum) {
+				ticks[count].position = position;
+				ticks[count].type = GOG_AXIS_TICK_MINOR;
+				ticks[count].label = NULL;
+				count++;
 			}
+		}
 	}
 
-	ticks = get_adjusted_tick_array (ticks, tick_nbr, count);
+	if (count > tick_nbr)
+		g_critical ("[GogAxisMap::log_calc_ticks] wrong memory allocation size");
+
+	ticks = g_renew (GogAxisTick, ticks, count);
 	gog_axis_set_ticks (axis, count, ticks);
 }
 
@@ -688,10 +731,11 @@ static const GogAxisMapDesc map_descs[] =
 	}
 };
 
+#ifdef GOFFICE_WITH_GTK
 static void
 gog_axis_map_set_by_num (GogAxis *axis, unsigned num)
 {
-	g_return_if_fail (GOG_AXIS (axis) != NULL);
+	g_return_if_fail (IS_GOG_AXIS (axis));
 
 	if (num >= 0 && num < G_N_ELEMENTS (map_descs))
 		g_object_set (G_OBJECT (axis), "map-name", map_descs[num].name, NULL);
@@ -704,7 +748,7 @@ gog_axis_map_populate_combo (GogAxis *axis, GtkComboBox *combo)
 {
 	unsigned i;
 
-	g_return_if_fail (GOG_AXIS (axis) != NULL);
+	g_return_if_fail (IS_GOG_AXIS (axis));
 
 	for (i = 0; i < G_N_ELEMENTS (map_descs); i++) {
 		gtk_combo_box_append_text (combo, _(map_descs[i].name));
@@ -713,13 +757,14 @@ gog_axis_map_populate_combo (GogAxis *axis, GtkComboBox *combo)
 			gtk_combo_box_set_active (combo, i);
 	}
 }
+#endif
 
 static void
 gog_axis_map_set (GogAxis *axis, char const *name) 
 {
 	unsigned i, map = 0;
 	
-	g_return_if_fail (GOG_AXIS (axis) != NULL);
+	g_return_if_fail (IS_GOG_AXIS (axis));
 
 	if (name != NULL)
 		for (i = 0; i < G_N_ELEMENTS(map_descs); i++) 
@@ -733,9 +778,12 @@ gog_axis_map_set (GogAxis *axis, char const *name)
 
 /**
  * gog_axis_map_is_valid
- * @axis : #GogAxis
+ * @map : a #GogAxisMap
  *
- * Return TRUE if map is valid, ie bounds are valid.
+ * Tests if @map was correctly initialized, i.e. if bounds are
+ * valid.
+ * 
+ * returns: %TRUE if map is valid
  **/
 
 gboolean
@@ -747,15 +795,17 @@ gog_axis_map_is_valid (GogAxisMap *map)
 }
 
 /**
- * gog_axis_map_new :
- * @axis : #GogAxis
- * @offset : start of plot area.
- * @length : length of plot area.
+ * gog_axis_map_new:
+ * @axis: a #GogAxis
+ * @offset: start of plot area.
+ * @length: length of plot area.
  *
- * Return a new GogAxisMap for data mapping to plot window.
+ * Creates a #GogAxisMap for data mapping to plot window.
  * offset and length are optional parameters to be used with 
  * gog_axis_map_to_view in order to translates data coordinates 
  * into canvas space.
+ *
+ * returns: a newly allocated #GogAxisMap.
  **/
 
 GogAxisMap *
@@ -763,7 +813,7 @@ gog_axis_map_new (GogAxis *axis, double offset, double length)
 {
 	GogAxisMap *map;
 	
-	g_return_val_if_fail (GOG_AXIS (axis) != NULL, NULL);
+	g_return_val_if_fail (IS_GOG_AXIS (axis), NULL);
 	
 	map = g_new0 (GogAxisMap, 1);
 
@@ -781,12 +831,14 @@ gog_axis_map_new (GogAxis *axis, double offset, double length)
 
 /**
  * gog_axis_map :
- * @map : #GogAxisMap
+ * @map : a #GogAxisMap
  * value : value to map to plot space.
+ * 
+ * Converts @value to plot coordinates. A value in [0,1.0] range means a data 
+ * within axis bounds.
  *
- * Return a value where [0,1.0] means a data within plot
- * bounds.
- * */
+ * returns: mapped value.
+ **/
 
 double 
 gog_axis_map (GogAxisMap *map,
@@ -799,8 +851,12 @@ gog_axis_map (GogAxisMap *map,
 
 /**
  * gog_axis_map_from_view :
- * @map : #GogAxisMap
+ * @map : a #GogAxisMap
  * @value : value to unmap from canvas space.
+ *
+ * Converts value from canvas space to data space.
+ *
+ * return value: value in data coordinates
  **/
 
 double 
@@ -812,26 +868,30 @@ gog_axis_map_from_view (GogAxisMap *map,
 
 /**
  * gog_axis_map_to_view :
- * @map : #GogAxisMap
- * @value : value to map to canvas space.
+ * @map : a #GogAxisMap
+ * @value : value to map to canvas space
  *
- * Return a value in canvas coordinates, where
- * [offset,offset+length] means a data within plot bounds.
+ * Converts value from data space to canvas space, using
+ * offset and length parameters given to gog_axis_map_new.
+ * 
+ * return value: a value in canvas coordinates
  **/
 
 double 
 gog_axis_map_to_view (GogAxisMap *map,
-			double value)
+		      double value)
 {
 	return map->desc->map_to_view (map, value);
 }
 
 /**
  * gog_axis_map_finite :
- * @map : #GogAxisMap
+ * @map : a #GogAxisMap
  * @value : value to test
  *
- * Returns TRUE if value means something in this map
+ * Tests wether @value is valid for the given @map.
+ * 
+ * return value: %TRUE if value means something
  **/
 
 gboolean 
@@ -842,9 +902,9 @@ gog_axis_map_finite (GogAxisMap *map, double value)
 
 /**
  * gog_axis_map_get_baseline :
- * @map : #GogAxisMap
+ * @map : a #GogAxisMap
  *
- * Returns the baseline for the given map, in view coordinates,
+ * Gets the baseline for @map, in view coordinates,
  * clipped to offset and offset+length, where offset and length
  * are the parameters of gog_axis_map_new.
  **/
@@ -857,17 +917,17 @@ gog_axis_map_get_baseline (GogAxisMap *map)
 
 /**
  * gog_axis_map_get_extents:
- * @map : #GogAxisMap
+ * @map : a #GogAxisMap
  * @start : start for this axis
  * @stop : stop for this axis
  *
- * Returns start and stop for the given axis map in data coordinates. If
+ * Gets start and stop for the given axis map in data coordinates. If
  * axis is not inverted, start = minimum and stop = maximum. If axis is invalid, 
  * it'll return arbitrary bounds. For example, an non inverted invalid X axis 
  * will have start set to 0.0 and stop set to 1.0.
  *
  * minimum or maximum can be NULL.
- * */
+ **/
 
 void
 gog_axis_map_get_extents (GogAxisMap *map, double *start, double *stop)
@@ -880,16 +940,16 @@ gog_axis_map_get_extents (GogAxisMap *map, double *start, double *stop)
 
 /**
  * gog_axis_map_get_bounds:
- * @map : #GogAxisMap
+ * @map : a #GogAxisMap
  * @minimum : minimum for this axis
  * @maximum : maximum for this axis
  *
- * Returns bounds for the given axis map in data coordinates. If axis is invalid, 
+ * Gets bounds for the given axis map in data coordinates. If axis is invalid, 
  * it'll return arbitrary bounds. For example, for an invalid x axis, minimum = 0.0
  * and maximum = 1.0. 
  *
  * minimum or maximum can be NULL.
- * */
+ **/
 
 void
 gog_axis_map_get_bounds (GogAxisMap *map, double *minimum, double *maximum)
@@ -898,9 +958,9 @@ gog_axis_map_get_bounds (GogAxisMap *map, double *minimum, double *maximum)
 }
 /**
  * gog_axis_map_free :
- * @map : #GogAxisMap
+ * @map : a #GogAxisMap
  *
- * Free GogAxisMap object.
+ * Frees #GogAxisMap object.
  **/
 
 void
@@ -923,7 +983,7 @@ gog_axis_auto_bound (GogAxis *axis)
 	double tmp;
 	gboolean user_defined;
 	
-	g_return_if_fail (GOG_AXIS (axis) != NULL);
+	g_return_if_fail (IS_GOG_AXIS (axis));
 
 	minimum = axis->min_val;
 	maximum = axis->max_val;
@@ -946,7 +1006,7 @@ gog_axis_set_ticks (GogAxis *axis, int tick_nbr, GogAxisTick *ticks)
 {
 	unsigned i;
 
-	g_return_if_fail (GOG_AXIS (axis) != NULL);
+	g_return_if_fail (IS_GOG_AXIS (axis));
 
 	if (axis->ticks != NULL) {
 		for (i = 0; i < axis->tick_nbr; i++)
@@ -962,7 +1022,7 @@ gog_axis_set_ticks (GogAxis *axis, int tick_nbr, GogAxisTick *ticks)
 static void 
 gog_axis_calc_ticks (GogAxis *axis)
 {
-	g_return_if_fail (GOG_AXIS (axis) != NULL);
+	g_return_if_fail (IS_GOG_AXIS (axis));
 
 	if (axis->is_discrete)
 		map_desc_discrete.calc_ticks (axis);
@@ -992,7 +1052,9 @@ enum {
 	AXIS_PROP_TYPE,
 	AXIS_PROP_INVERT,
 	AXIS_PROP_MAP,
-	AXIS_PROP_ASSIGNED_FORMAT_STR_XL
+	AXIS_PROP_ASSIGNED_FORMAT_STR_XL,
+	AXIS_PROP_CIRCULAR_ROTATION,
+	AXIS_PROP_POLAR_UNIT
 };
 
 /*****************************************************************************/
@@ -1069,9 +1131,11 @@ role_label_can_add (GogObject const *parent)
  * Absorbs a reference to @fmt, and accepts NULL.
  * returns TRUE if things changed
  **/
-static gboolean
+gboolean
 gog_axis_set_format (GogAxis *axis, GOFormat *fmt)
 {
+	g_return_val_if_fail (IS_GOG_AXIS (axis), FALSE);
+
 	if (go_format_eq (fmt, axis->assigned_format)) {
 		go_format_unref (fmt);
 		return FALSE;
@@ -1079,9 +1143,24 @@ gog_axis_set_format (GogAxis *axis, GOFormat *fmt)
 	if (axis->assigned_format != NULL)
 		go_format_unref (axis->assigned_format);
 	axis->assigned_format = fmt;
+
+	gog_object_request_update (GOG_OBJECT (axis));
 	return TRUE;
 }
 
+/**
+ * gog_axis_get_format :
+ * @axis :#GogAxis
+ *
+ * Returns the format assigned to @axis but does not add a reference.
+ **/
+GOFormat *
+gog_axis_get_format (GogAxis const *axis)
+{
+	g_return_val_if_fail (IS_GOG_AXIS (axis), NULL);
+	return axis->assigned_format;
+}
+
 static void
 gog_axis_set_property (GObject *obj, guint param_id,
 		       GValue const *value, GParamSpec *pspec)
@@ -1124,6 +1203,23 @@ gog_axis_set_property (GObject *obj, guint param_id,
 		calc_ticks = resized;
 		break;
 	}
+	case AXIS_PROP_CIRCULAR_ROTATION:
+		axis->circular_rotation = CLAMP (g_value_get_double (value),
+						 GOG_AXIS_CIRCULAR_ROTATION_MIN,
+						 GOG_AXIS_CIRCULAR_ROTATION_MAX);
+		break;
+	case AXIS_PROP_POLAR_UNIT: {
+		char const *str = g_value_get_string (value);
+		unsigned int i;
+		for (i = 0; i < G_N_ELEMENTS (polar_units); i++) {
+			if (g_ascii_strcasecmp (str, polar_units[i].name) == 0) {
+				axis->polar_unit = i;
+				break;
+			}
+		}
+		resized = calc_ticks = TRUE;
+		break;
+	}
 
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 		 return; /* NOTE : RETURN */
@@ -1161,6 +1257,12 @@ gog_axis_get_property (GObject *obj, guint param_id,
 		else
 			g_value_set_static_string (value, NULL);
 		break;
+	case AXIS_PROP_CIRCULAR_ROTATION:
+		g_value_set_double (value, axis->circular_rotation);
+		break;
+	case AXIS_PROP_POLAR_UNIT:
+		g_value_set_string (value, polar_units[axis->polar_unit].name);
+		break;
 
 	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 		 break;
@@ -1202,7 +1304,7 @@ gog_axis_finalize (GObject *obj)
  * @i :
  * @user_defined : an optionally NULL pointr to gboolean
  *
- * Returns the value of axis element @i and sets @user_defined or
+ * Returns: the value of axis element @i and sets @user_defined or
  * 	NaN on error
  **/
 double
@@ -1213,7 +1315,7 @@ gog_axis_get_entry (GogAxis const *axis, GogAxisElemType i, gboolean *user_defin
 	if (user_defined)
 		*user_defined = FALSE;
 
-	g_return_val_if_fail (GOG_AXIS (axis) != NULL, go_nan);
+	g_return_val_if_fail (IS_GOG_AXIS (axis), go_nan);
 	g_return_val_if_fail (i >= GOG_AXIS_ELEM_MIN && i < GOG_AXIS_ELEM_MAX_ENTRY, go_nan);
 
 	if (i != GOG_AXIS_ELEM_CROSS_POINT)
@@ -1315,6 +1417,24 @@ gog_axis_update (GogObject *obj)
 		gog_object_emit_changed (GOG_OBJECT (obj), TRUE);
 }
 
+#ifdef GOFFICE_WITH_GTK
+
+typedef struct {
+	GladeXML 	*gui;
+	GogAxis		*axis;
+	GtkWidget 	*format_selector;	
+} GogAxisPrefState;
+
+static void
+gog_axis_pref_state_free (GogAxisPrefState *state)
+{
+	if (state->axis != NULL)
+		g_object_unref (state->axis);
+	if (state->gui != NULL)
+		g_object_unref (state->gui);
+	g_free (state);
+}
+
 static void
 cb_axis_toggle_changed (GtkToggleButton *toggle_button, GObject *axis)
 {
@@ -1329,8 +1449,18 @@ typedef struct {
 	GtkToggleButton *toggle;
 	GogDataset *set;
 	unsigned dim;
+	gulong update_editor_handler;
+	gulong changed_handler;
 } ElemToggleData;
 
+static void
+elem_toggle_data_free (ElemToggleData *data)
+{
+	g_signal_handler_disconnect (G_OBJECT (data->set), data->update_editor_handler);
+	g_signal_handler_disconnect (G_OBJECT (data->set), data->changed_handler);
+	g_free (data);
+}
+
 static void
 cb_enable_dim (GtkToggleButton *toggle_button, ElemToggleData *closure)
 {
@@ -1364,12 +1494,18 @@ cb_axis_bound_changed (GogObject *axis, gboolean resize, ElemToggleData *closure
 	}
 }
 
+static void
+cb_update_dim_editor (GogObject *gobj, ElemToggleData *closure)
+{
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (closure->toggle),
+		gog_dataset_get_dim (closure->set, closure->dim) == NULL);
+}
+
 static void
 make_dim_editor (GogDataset *set, GtkTable *table, unsigned dim,
 		 GogDataAllocator *dalloc, char const * const *dim_name)
 {
 	ElemToggleData *info;
-	GClosure *closure;
 	GtkWidget *editor = gog_data_allocator_editor (dalloc, set, dim, GOG_DATA_SCALAR);
 	char *txt = g_strconcat (_(dim_name [dim]), ":", NULL);
 	GtkWidget *toggle = gtk_check_button_new_with_mnemonic (txt);
@@ -1380,29 +1516,32 @@ make_dim_editor (GogDataset *set, GtkTable *table, unsigned dim,
 	info->set = set;
 	info->dim = dim;
 	info->toggle = GTK_TOGGLE_BUTTON (toggle);
+	
 	g_signal_connect (G_OBJECT (toggle),
-		"toggled",
-		G_CALLBACK (cb_enable_dim), info);
+			  "toggled",
+			  G_CALLBACK (cb_enable_dim), info);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (toggle),
-		gog_dataset_get_dim (set, dim) == NULL);
+				      gog_dataset_get_dim (set, dim) == NULL);
 
-	closure = g_cclosure_new (G_CALLBACK (cb_axis_bound_changed),
-				  info, (GClosureNotify)g_free);
-	g_object_watch_closure (G_OBJECT (toggle), closure);
-	g_signal_connect_closure (G_OBJECT (set),
-		"changed",
-		closure, FALSE);
+	info->update_editor_handler = g_signal_connect (G_OBJECT (set), 
+							"update-editor", 
+							G_CALLBACK (cb_update_dim_editor), info);
+	info->changed_handler = g_signal_connect (G_OBJECT (set),
+						  "changed",
+						  G_CALLBACK (cb_axis_bound_changed), info);
+	g_object_weak_ref (G_OBJECT (toggle), (GWeakNotify) elem_toggle_data_free, info);
 
 	gtk_table_attach (table, toggle,
 		0, 1, dim + 1, dim + 2, GTK_FILL, 0, 0, 0);
 	gtk_table_attach (table, editor,
 		1, 2, dim + 1, dim + 2, GTK_FILL | GTK_EXPAND, 0, 0, 0);
+	
 }
 
 static void
 cb_axis_fmt_changed (G_GNUC_UNUSED GtkWidget *widget,
 		     char *fmt,
-		     GObject *axis)
+		     GogAxis *axis)
 {
 	g_object_set (axis, "assigned-format-string-XL", fmt, NULL);
 }
@@ -1414,14 +1553,44 @@ cb_map_combo_changed (GtkComboBox *combo,
 	gog_axis_map_set_by_num (axis, gtk_combo_box_get_active (combo));
 }
 
-#if 0
 static void
-cb_axis_fmt_assignment_toggled (GtkToggleButton *toggle_button, GtkNotebook *notebook)
+gog_axis_populate_polar_unit_combo (GogAxis *axis, GtkComboBox *combo)
 {
-	/* any time the toggle changes assume the user wanted to select the page too */
-	gtk_notebook_set_current_page (notebook, 0); /* assume it is the first page */ 
+	unsigned i, id = 0;
+
+	g_return_if_fail (IS_GOG_AXIS (axis));
+
+	for (i = 0; i < G_N_ELEMENTS (polar_units); i++) {
+		gtk_combo_box_append_text (combo, _(polar_units[i].name));
+		if (polar_units[i].unit == axis->polar_unit)
+			id = i;
+	}
+	gtk_combo_box_set_active (combo, id);
+}
+
+static void
+cb_polar_unit_changed (GtkComboBox *combo,
+		       GogAxisPrefState *state)
+{
+	GogAxis *axis = state->axis;
+	GOFormat *format;
+
+	axis->polar_unit = gtk_combo_box_get_active (combo);
+	format = go_format_new_from_XL (polar_units[axis->polar_unit].xl_format, FALSE);
+
+	if (gog_axis_set_format (axis, format) &&
+	    state->format_selector != NULL) 
+		go_format_sel_set_style_format (GO_FORMAT_SEL (state->format_selector), format);
+}
+
+static void
+cb_rotation_changed (GtkSpinButton *spin, GogAxis *axis)
+{
+	axis->circular_rotation = CLAMP (gtk_spin_button_get_value (spin), 
+					 GOG_AXIS_CIRCULAR_ROTATION_MIN, 
+					 GOG_AXIS_CIRCULAR_ROTATION_MAX);
+	gog_object_emit_changed (GOG_OBJECT (axis), TRUE);
 }
-#endif
 
 static void
 gog_axis_populate_editor (GogObject *gobj, 
@@ -1437,6 +1606,7 @@ gog_axis_populate_editor (GogObject *gobj,
 	GtkTable  *table;
 	unsigned i = 0;
 	GogAxis *axis = GOG_AXIS (gobj);
+	GogAxisPrefState *state;
 	GogDataset *set = GOG_DATASET (gobj);
 	GladeXML *gui;
 
@@ -1444,6 +1614,11 @@ gog_axis_populate_editor (GogObject *gobj,
 	if (gui == NULL)
 		return;
 
+	state = g_new0 (GogAxisPrefState, 1);
+	state->gui = gui;
+	state->axis = axis;
+	g_object_ref (G_OBJECT (axis));
+
 	/* Bounds Page */
 	table = GTK_TABLE (glade_xml_get_widget (gui, "bound_table"));
 	if (axis->is_discrete) {
@@ -1481,6 +1656,24 @@ gog_axis_populate_editor (GogObject *gobj,
 		gtk_widget_hide (w);
 	}
 
+	if (!axis->is_discrete && gog_axis_get_atype (axis) == GOG_AXIS_CIRCULAR) {
+		GtkWidget *w = glade_xml_get_widget (gui, "polar_unit_combo");
+		gog_axis_populate_polar_unit_combo (axis, GTK_COMBO_BOX (w));
+		g_signal_connect (G_OBJECT (w),
+				  "changed",
+				  G_CALLBACK (cb_polar_unit_changed),
+				  state);
+
+		w = glade_xml_get_widget (gui, "circular_rotation_spinbutton");
+		gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), axis->circular_rotation);
+		g_signal_connect_object (G_OBJECT (w), "value-changed",
+					 G_CALLBACK (cb_rotation_changed),
+					 axis, 0);
+	} else {
+		GtkWidget *w = glade_xml_get_widget (gui, "circular_table");
+		gtk_widget_hide (w);
+	}
+
 	for (i = 0; i < G_N_ELEMENTS (toggle_props) ; i++) {
 		gboolean cur_val;
 		GtkWidget *w = glade_xml_get_widget (gui, toggle_props[i]);
@@ -1501,7 +1694,9 @@ gog_axis_populate_editor (GogObject *gobj,
 
 	/* Format page */
 	if (!axis->is_discrete && gog_axis_get_atype (axis) != GOG_AXIS_PSEUDO_3D) {
-		w = go_format_sel_new ();
+		w = go_format_sel_new_full (TRUE);
+		state->format_selector = w;
+
 		if (axis->assigned_format != NULL && !go_format_is_general (axis->assigned_format))
 			go_format_sel_set_style_format (GO_FORMAT_SEL (w),
 				axis->assigned_format);
@@ -1509,19 +1704,7 @@ gog_axis_populate_editor (GogObject *gobj,
 			go_format_sel_set_style_format (GO_FORMAT_SEL (w),
 				axis->format);
 
-#if 0
-		/* TOO CHEESY to go into production
-		 * We need a way to toggle auto vs user formats
-		 * but the selector is too tall already
-		 * disable for now */
-		cbox = gtk_check_button_new_with_label (_("Format"));
-		g_signal_connect (G_OBJECT (cbox),
-			"toggled",
-			G_CALLBACK (cb_axis_fmt_assignment_toggled), notebook);
-		gtk_notebook_prepend_page (GTK_NOTEBOOK (notebook), w, cbox);
-#else
 		gog_editor_add_page (editor, w, _("Format"));
-#endif
 
 		gtk_widget_show (w);
 		g_signal_connect (G_OBJECT (w),
@@ -1529,11 +1712,12 @@ gog_axis_populate_editor (GogObject *gobj,
 	}
 
 	w = glade_xml_get_widget (gui, "axis_pref_box");
-	g_object_set_data_full (G_OBJECT (w), "gui", gui,
-				(GDestroyNotify)g_object_unref);
+	g_object_set_data_full (G_OBJECT (w), "state", state,
+				(GDestroyNotify)gog_axis_pref_state_free);
 
 	gog_editor_set_store_page (editor, &axis_pref_page);
 }
+#endif
 
 static void
 gog_axis_init_style (GogStyledObject *gso, GogStyle *style)
@@ -1590,11 +1774,24 @@ gog_axis_class_init (GObjectClass *gobject_klass)
 		g_param_spec_string ("assigned-format-string-XL", NULL,
 			"The user assigned format to use for non-discrete axis labels (XL format)",
 			"General", G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+	g_object_class_install_property (gobject_klass, AXIS_PROP_CIRCULAR_ROTATION,
+		g_param_spec_double ("circular-rotation", "Rotation of circular axis", 
+				     "Rotation of circular axis",
+				     GOG_AXIS_CIRCULAR_ROTATION_MIN, 
+				     GOG_AXIS_CIRCULAR_ROTATION_MAX,
+				     0.0, G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
+	g_object_class_install_property (gobject_klass, AXIS_PROP_POLAR_UNIT,
+		g_param_spec_string ("polar-unit", "Polar axis set unit", 
+				     "Polar axis set unit", 
+				     polar_units[GOG_AXIS_POLAR_UNIT_DEGREES].name,
+				     G_PARAM_READWRITE|GOG_PARAM_PERSISTENT));
 
 	gog_object_register_roles (gog_klass, roles, G_N_ELEMENTS (roles));
 
 	gog_klass->update	= gog_axis_update;
+#ifdef GOFFICE_WITH_GTK
 	gog_klass->populate_editor	= gog_axis_populate_editor;
+#endif
 	gog_klass->view_type	= gog_axis_view_get_type ();
 	style_klass->init_style = gog_axis_init_style;
 }
@@ -1618,6 +1815,9 @@ gog_axis_init (GogAxis *axis)
 
 	gog_axis_map_set (axis, NULL);
 
+	axis->polar_unit = GOG_AXIS_POLAR_UNIT_DEGREES;
+	axis->circular_rotation = 0;
+
 	axis->ticks = NULL;
 	axis->tick_nbr = 0;
 }
@@ -1665,7 +1865,7 @@ GSF_CLASS_FULL (GogAxis, gog_axis,
 GogAxisType
 gog_axis_get_atype (GogAxis const *axis)
 {
-	g_return_val_if_fail (GOG_AXIS (axis) != NULL, GOG_AXIS_UNKNOWN);
+	g_return_val_if_fail (IS_GOG_AXIS (axis), GOG_AXIS_UNKNOWN);
 	return axis->type;
 }
 
@@ -1673,12 +1873,12 @@ gog_axis_get_atype (GogAxis const *axis)
  * gog_axis_is_center_on_ticks :
  * @axis : #GogAxis
  * 
- * Returns TRUE if labels are centered on ticks when @axis is discrete
+ * Returns: TRUE if labels are centered on ticks when @axis is discrete
  **/ 
 gboolean
 gog_axis_is_center_on_ticks (GogAxis const *axis)
 {
-	g_return_val_if_fail (GOG_AXIS (axis) != NULL, FALSE);
+	g_return_val_if_fail (IS_GOG_AXIS (axis), FALSE);
 	return axis->center_on_ticks;
 }
 
@@ -1686,13 +1886,13 @@ gog_axis_is_center_on_ticks (GogAxis const *axis)
  * gog_axis_is_discrete :
  * @axis : #GogAxis
  * 
- * Returns TRUE if @axis enumerates a set of discrete items, rather than a
+ * Returns: TRUE if @axis enumerates a set of discrete items, rather than a
  * continuous value
  **/ 
 gboolean
 gog_axis_is_discrete (GogAxis const *axis)
 {
-	g_return_val_if_fail (GOG_AXIS (axis) != NULL, FALSE);
+	g_return_val_if_fail (IS_GOG_AXIS (axis), FALSE);
 	return axis->is_discrete;
 }
 
@@ -1700,12 +1900,12 @@ gog_axis_is_discrete (GogAxis const *axis)
  * gog_axis_is_inverted :
  * @axis : #GogAxis
  * 
- * Returns TRUE if @axis is inverted.
+ * Returns: TRUE if @axis is inverted.
  **/ 
 gboolean
 gog_axis_is_inverted (GogAxis const *axis)
 {
-	g_return_val_if_fail (GOG_AXIS (axis) != NULL, FALSE);
+	g_return_val_if_fail (IS_GOG_AXIS (axis), FALSE);
 	return axis->inverted;
 }
 
@@ -1720,7 +1920,7 @@ gog_axis_is_inverted (GogAxis const *axis)
 gboolean
 gog_axis_get_bounds (GogAxis const *axis, double *minima, double *maxima)
 {
-	g_return_val_if_fail (GOG_AXIS (axis) != NULL, FALSE);
+	g_return_val_if_fail (IS_GOG_AXIS (axis), FALSE);
 	g_return_val_if_fail (minima != NULL, FALSE);
 	g_return_val_if_fail (maxima != NULL, FALSE);
 
@@ -1730,17 +1930,64 @@ gog_axis_get_bounds (GogAxis const *axis, double *minima, double *maxima)
 	return go_finite (*minima) && go_finite (*maxima) && *minima < *maxima;
 }
 
+/**
+ * gog_axis_set_bounds :
+ * @axis : #GogAxis
+ * @minimum : axis low bound
+ * @maximum : axis high bound
+ *
+ * Sets axis bounds. If minimum or maximum are not finite values, corresponding
+ * bound remains unchanged.
+ **/
+void
+gog_axis_set_bounds (GogAxis *axis, double minimum, double maximum)
+{
+	g_return_if_fail (IS_GOG_AXIS (axis));
+
+	if (go_finite (minimum)) {
+		gog_dataset_set_dim (GOG_DATASET (axis), GOG_AXIS_ELEM_MIN, 
+				     go_data_scalar_val_new (minimum), NULL);
+	}
+	if (go_finite (maximum)) {
+		gog_dataset_set_dim (GOG_DATASET (axis), GOG_AXIS_ELEM_MAX,
+				     go_data_scalar_val_new (maximum), NULL);
+	}
+}
+
+/**
+ * gog_axis_set_extents :
+ * @axis : #GogAxis
+ * @start : axis start bound
+ * @stop : axis stop bound
+ *
+ * Set axis exents. It's a convenience function that sets axis bounds taking 
+ * into account invert flag.
+ **/
+void
+gog_axis_set_extents (GogAxis *axis, double start, double stop)
+{
+	g_return_if_fail (IS_GOG_AXIS (axis));
+
+	if (axis->inverted)
+		gog_axis_set_bounds (axis, stop, start);
+	else
+		gog_axis_set_bounds (axis, start, stop);
+}
+
+
 /**
  * gog_axis_get_ticks :
  * @axis : #GogAxis
- * @ticks : result
+ * @ticks : an array of #GogAxisTick
  *
- * Retrieve an array of tick descriptions, and return the number of ticks.
+ * An accessor to @axis->ticks.
+ *
+ * return value: number of ticks
  **/
 unsigned 
 gog_axis_get_ticks (GogAxis *axis, GogAxisTick **ticks)
 {
-	g_return_val_if_fail (GOG_AXIS (axis) != NULL, 0);
+	g_return_val_if_fail (IS_GOG_AXIS (axis), 0);
 	g_return_val_if_fail (ticks != NULL, 0);
 
 	*ticks = axis->ticks;
@@ -1749,16 +1996,16 @@ gog_axis_get_ticks (GogAxis *axis, GogAxisTick **ticks)
 
 /**
  * gog_axis_get_labels :
- * @axi : #GogAxis
- * @plot_that_labeled_axis : #GogPlot
+ * @axis : a #GogAxis
+ * @plot_that_labeled_axis : a #GogPlot
  *
- * Return the possibly NULL #GOData used as a label for this axis
+ * return value: the possibly NULL #GOData used as a label for this axis
  * along with the plot that it was associated with
  **/
 GOData *
 gog_axis_get_labels (GogAxis const *axis, GogPlot **plot_that_labeled_axis)
 {
-	g_return_val_if_fail (GOG_AXIS (axis) != NULL, NULL);
+	g_return_val_if_fail (IS_GOG_AXIS (axis), NULL);
 
 	if (axis->is_discrete) {
 		if (plot_that_labeled_axis != NULL)
@@ -1780,7 +2027,7 @@ gog_axis_get_labels (GogAxis const *axis, GogPlot **plot_that_labeled_axis)
 void
 gog_axis_add_contributor (GogAxis *axis, GogObject *contrib)
 {
-	g_return_if_fail (GOG_AXIS (axis) != NULL);
+	g_return_if_fail (IS_GOG_AXIS (axis));
 	g_return_if_fail (g_slist_find (axis->contributors, contrib) == NULL);
 
 	axis->contributors = g_slist_prepend (axis->contributors, contrib);
@@ -1800,7 +2047,7 @@ gog_axis_del_contributor (GogAxis *axis, GogObject *contrib)
 {
 	gboolean update = FALSE;
 
-	g_return_if_fail (GOG_AXIS (axis) != NULL);
+	g_return_if_fail (IS_GOG_AXIS (axis));
 	g_return_if_fail (g_slist_find (axis->contributors, contrib) != NULL);
 
 	if (axis->min_contrib == contrib) {
@@ -1823,7 +2070,7 @@ gog_axis_clear_contributors (GogAxis *axis)
 	GSList *ptr, *list;
 	GogAxisSet filter;
 
-	g_return_if_fail (GOG_AXIS (axis) != NULL);
+	g_return_if_fail (IS_GOG_AXIS (axis));
 
 	filter = 1 << axis->type;
 	list = g_slist_copy (axis->contributors);
@@ -1835,7 +2082,7 @@ gog_axis_clear_contributors (GogAxis *axis)
 GSList const *
 gog_axis_contributors (GogAxis *axis)
 {
-	g_return_val_if_fail (GOG_AXIS (axis) != NULL, NULL);
+	g_return_val_if_fail (IS_GOG_AXIS (axis), NULL);
 
 	return axis->contributors;
 }
@@ -1848,7 +2095,7 @@ gog_axis_contributors (GogAxis *axis)
 void
 gog_axis_bound_changed (GogAxis *axis, GogObject *contrib)
 {
-	g_return_if_fail (GOG_AXIS (axis) != NULL);
+	g_return_if_fail (IS_GOG_AXIS (axis));
 
 	gog_object_request_update (GOG_OBJECT (axis));
 }
@@ -1857,7 +2104,7 @@ gog_axis_bound_changed (GogAxis *axis, GogObject *contrib)
  * @axis: #GogAxis
  * @major: whether to retrieve major or minor grid line.
  *
- * Returns a pointer to GridLine object associated to given axis, NULL
+ * Returns: a pointer to GridLine object associated to given axis, NULL
  * if it doesn't exists.
  **/
 GogGridLine *
@@ -1877,6 +2124,73 @@ gog_axis_get_grid_line (GogAxis *axis, gboolean major)
 	return NULL;
 }
 
+/**
+ * gog_axis_set_polar_unit:
+ * @axis: a #GogAxis
+ * @unit: #GogAxisPolarUnit
+ *
+ * Sets unit of a circular axis. See #GogAxisPolarUnit for valid
+ * values. 
+ **/
+
+void
+gog_axis_set_polar_unit (GogAxis *axis, GogAxisPolarUnit unit)
+{
+	g_return_if_fail (IS_GOG_AXIS (axis));
+
+	axis->polar_unit = CLAMP (unit, 0, GOG_AXIS_POLAR_UNIT_MAX - 1);
+}
+
+/**
+ * gog_axis_get_polar_unit:
+ * @axis: a #GogAxis
+ *
+ * returns: unit of @axis if it's a circular axis of a polar
+ * axis set, -1 otherwise.
+ **/
+
+GogAxisPolarUnit
+gog_axis_get_polar_unit (GogAxis *axis)
+{
+	g_return_val_if_fail (IS_GOG_AXIS (axis), 0);
+
+	return axis->polar_unit;
+}
+
+/**
+ * gog_axis_get_circular_perimeter:
+ * @axis: a #GogAxis
+ *
+ * returns: perimeter of a circular #GogAxis of a polar axis set.
+ * 
+ * 	radians: 2*pi
+ * 	degrees: 360.0
+ * 	grads  : 400.0
+ **/
+
+double
+gog_axis_get_polar_perimeter (GogAxis *axis)
+{
+	g_return_val_if_fail (IS_GOG_AXIS (axis), 0.0);
+
+	return polar_units[axis->polar_unit].perimeter;
+}
+
+/**
+ * gog_axis_get_circular_rotation:
+ * @axis: a #GogAxis
+ *
+ * returns: rotation of a circular #GogAxis.
+ **/
+
+double
+gog_axis_get_circular_rotation (GogAxis *axis)
+{
+	g_return_val_if_fail (IS_GOG_AXIS (axis), 0.0);
+
+	return axis->circular_rotation;
+}
+
 /****************************************************************************/
 
 typedef GogAxisBaseView		GogAxisView;
@@ -1989,7 +2303,7 @@ gog_axis_view_size_allocate (GogView *view, GogViewAllocation const *bbox)
 					if (type == GOG_AXIS_X) {
 						child_bbox.x = plot_area->x + 
 							(plot_area->w - req.w) / 2.0;
-						child_bbox.w = plot_area->w;
+						child_bbox.w = req.w;
 						child_bbox.h = req.h;
 						if (axis_pos != GOG_AXIS_AT_HIGH) {
 							child_bbox.y = tmp.y + tmp.h - req.h;
@@ -2001,7 +2315,7 @@ gog_axis_view_size_allocate (GogView *view, GogViewAllocation const *bbox)
 					} else { 
 						child_bbox.y = plot_area->y + 
 							(plot_area->h - req.h) / 2.0;
-						child_bbox.h = plot_area->h;
+						child_bbox.h = req.h;
 						child_bbox.w = req.w;
 						if (axis_pos != GOG_AXIS_AT_HIGH) {
 							child_bbox.x = tmp.x;
