@@ -38,21 +38,11 @@ typedef struct {
 
 typedef struct _GogChartMap GogChartMap;
 
-struct _GogChartMap {
-	GogChart 		*chart;
-	GogViewAllocation	 area;
-	gpointer	 	 data;
-	GogAxisMap		*axis_map[3];
-	gboolean		 is_valid;
-
-	void (*map_2D_to_view)	(GogChartMap *map, double x, double y, double *u, double *v);
-};
-
 GogChartMap 	*gog_chart_map_new 		(GogChart *chart, GogViewAllocation const *area,
 						 GogAxis *axis0, GogAxis *axis1, GogAxis *axis2,
 						 gboolean fill_area);
 void 		 gog_chart_map_2D_to_view	(GogChartMap *map, double x, double y, double *u, double *v);
-GogAxisMap	*gog_chart_map_get_axis_map 	(GogChartMap *map, unsigned i);
+GogAxisMap	*gog_chart_map_get_axis_map 	(GogChartMap *map, unsigned int index);
 gboolean	 gog_chart_map_is_valid 	(GogChartMap *map);
 void		 gog_chart_map_free 		(GogChartMap *map);
 
@@ -66,8 +56,8 @@ GType gog_chart_get_type (void);
 
 gboolean  gog_chart_get_position  (GogChart const *chart, unsigned *x, unsigned *y,
 				   unsigned *cols, unsigned *rows);
-void	  gog_chart_set_position  (GogChart *chart, unsigned x, unsigned y,
-				   unsigned cols, unsigned rows);
+void	  gog_chart_set_position  (GogChart *chart, unsigned int x, unsigned int y,
+				   unsigned int cols, unsigned int rows);
 gboolean  gog_chart_get_plot_area (GogChart *chart, GogViewAllocation *plot_area);
 void 	  gog_chart_set_plot_area (GogChart *chart, GogViewAllocation const *plot_area);
 
@@ -81,7 +71,7 @@ GSList	*gog_chart_get_plots	   (GogChart const *chart);
 GogAxisSet gog_chart_get_axis_set    (GogChart const *chart);
 gboolean gog_chart_axis_set_is_valid (GogChart const *chart, GogAxisSet type);
 gboolean gog_chart_axis_set_assign   (GogChart *chart, GogAxisSet type);
-GSList	*gog_chart_get_axes	     (GogChart const *chart, GogAxisType type);
+GSList	*gog_chart_get_axes	     (GogChart const *chart, GogAxisType target);
 
 GogGrid *gog_chart_get_grid	     (GogChart const *chart);
 
