@@ -252,7 +252,7 @@ cb_size_elements (unsigned i, GogStyle const *style,
 	GogView *view = GOG_VIEW (glv);
 	GOGeometryAABR aabr;
 	
-	gog_renderer_get_text_AABR (view->renderer, name, &aabr);
+	gog_renderer_get_text_AABR (view->renderer, name, FALSE, &aabr);
 
 	if (glv->element_width < aabr.w)
 		glv->element_width = aabr.w;
@@ -361,6 +361,7 @@ cb_swatch_scale (unsigned i, GogStyle const *style, char const *name,
 }
 
 typedef struct {
+	int count;
 	GogView const *view;
 	double x, y;
 	double element_step_x, element_step_y;
@@ -371,7 +372,7 @@ typedef struct {
 } RenderClosure;
 
 static void
-cb_render_elements (unsigned i, GogStyle const *base_style, char const *name,
+cb_render_elements (unsigned index, GogStyle const *base_style, char const *name,
 		    RenderClosure *data)
 {
 	GogView const *view = data->view;
@@ -380,8 +381,8 @@ cb_render_elements (unsigned i, GogStyle const *base_style, char const *name,
 	GogStyle *style = NULL;
 	GogViewAllocation pos, rectangle;
 
-	if (i > 0) {
-		if ((i % glv->element_per_blocks) != 0) {
+	if (data->count > 0) {
+		if ((data->count % glv->element_per_blocks) != 0) {
 			data->x += data->element_step_x;
 			data->y += data->element_step_y;
 		} else {
@@ -389,6 +390,7 @@ cb_render_elements (unsigned i, GogStyle const *base_style, char const *name,
 			data->y += data->block_step_y;
 		}
 	}
+	data->count++;
 	
 	if (base_style->interesting_fields & GOG_STYLE_LINE) { /* line and marker */
 		style = gog_style_dup (base_style);
@@ -421,7 +423,7 @@ cb_render_elements (unsigned i, GogStyle const *base_style, char const *name,
 	pos.x = data->x + glv->label_offset;
 	pos.y = data->y + glv->element_height / 2.0;
 	pos.w = pos.h = -1;
-	gog_renderer_draw_text (renderer, name, &pos, GTK_ANCHOR_W, NULL);
+	gog_renderer_draw_text (renderer, name, &pos, GTK_ANCHOR_W, FALSE);
 
 	if (style != base_style && style != NULL)
 		g_object_unref (style);
@@ -473,6 +475,7 @@ gog_legend_view_render (GogView *v, GogViewAllocation const *bbox)
 		data.line_path[2].code = ART_END;
 	}
 	
+	data.count = 0;
 	data.view = v;
 	data.x = v->residual.x;
 	data.y = v->residual.y;
