@@ -101,6 +101,7 @@ typedef struct {
 
 	unsigned use_parent_as_proxy : 1; /* when we change, pretend it was our parent */
 	unsigned can_manual_size : 1; 
+	unsigned roles_allocated : 1;
 
 	/* Virtuals */
 	void	     (*update)		(GogObject *obj);
@@ -119,6 +120,7 @@ typedef struct {
 	void (*child_removed)	   (GogObject *parent, GogObject *child);
 	void (*child_name_changed) (GogObject const *obj, GogObject const *child);
 	void (*children_reordered) (GogObject *obj);
+	void (*update_editor)	   (GogObject *obj);
 } GogObjectClass;
 
 #define GOG_OBJECT_TYPE		(gog_object_get_type ())
@@ -135,7 +137,7 @@ GType gog_object_get_type (void);
 
 typedef void (*GogDataDuplicator) (GogDataset const *src, GogDataset *dst);
 
-GogObject   *gog_object_dup		 (GogObject const *obj, GogObject *new_parent, GogDataDuplicator dup);
+GogObject   *gog_object_dup		 (GogObject const *src, GogObject *new_parent, GogDataDuplicator datadup);
 GogObject   *gog_object_get_parent	 (GogObject const *obj);
 GogObject   *gog_object_get_parent_typed (GogObject const *obj, GType t);
 GogGraph    *gog_object_get_graph	 (GogObject const *obj);
@@ -145,11 +147,12 @@ char const  *gog_object_get_name	 (GogObject const *obj);
 void	     gog_object_set_name	 (GogObject *obj, char *name, GError **err);
 GSList      *gog_object_get_children	 (GogObject const *obj, GogObjectRole const *filter);
 GogObject   *gog_object_get_child_by_role(GogObject const *obj, GogObjectRole const *role);
+GogObject   *gog_object_get_child_by_name(GogObject const *obj, char const *name);
 gpointer     gog_object_get_editor	 (GogObject *obj,
 					  GogDataAllocator *dalloc, GOCmdContext *cc);
-GogView	  *gog_object_new_view	 	 (GogObject const *obj, GogView *view);
+GogView	  *gog_object_new_view		 (GogObject const *obj, GogView *parent);
 gboolean   gog_object_is_deletable	 (GogObject const *obj);
-GSList    *gog_object_possible_additions (GogObject const *obj);
+GSList    *gog_object_possible_additions (GogObject const *parent);
 GogObject *gog_object_add_by_role	 (GogObject *parent,
 					  GogObjectRole const *role, GogObject *child);
 GogObject   *gog_object_add_by_name	 (GogObject *parent,
@@ -160,7 +163,7 @@ GogObject	 *gog_object_reorder	 (GogObject const *obj,
 					  gboolean inc, gboolean goto_max);
 
 GogObjectPosition gog_object_get_position_flags	   (GogObject const *obj, GogObjectPosition mask);
-gboolean	  gog_object_set_position_flags	   (GogObject *obj, GogObjectPosition p, GogObjectPosition mask);
+gboolean          gog_object_set_position_flags    (GogObject *obj, GogObjectPosition flags, GogObjectPosition mask);
 void	          gog_object_get_manual_position   (GogObject *obj, GogViewAllocation *pos);
 void 		  gog_object_set_manual_position   (GogObject *obj, GogViewAllocation const *pos);
 
@@ -172,15 +175,15 @@ GogObjectRole const *gog_object_find_role_by_name (GogObject const *obj,
 						   char const *role);
 
 /* protected */
-void	 gog_object_update		(GogObject *obj);
-gboolean gog_object_request_update	(GogObject *obj);
-void 	 gog_object_emit_changed	(GogObject *obj, gboolean size);
-gboolean gog_object_clear_parent	(GogObject *obj);
-gboolean gog_object_set_parent	 	(GogObject *child, GogObject *parent,
-					 GogObjectRole const *role, unsigned id);
-void 	 gog_object_register_roles	(GogObjectClass *klass,
-					 GogObjectRole const *roles, unsigned n_roles);
-void 	 gog_object_unregister_role	(GogObjectClass *klass, char const *id);
+void	 gog_object_update		  (GogObject *obj);
+gboolean gog_object_request_update	  (GogObject *obj);
+void 	 gog_object_emit_changed	  (GogObject *obj, gboolean size);
+gboolean gog_object_clear_parent	  (GogObject *obj);
+gboolean gog_object_set_parent		  (GogObject *child, GogObject *parent,
+					  GogObjectRole const *role, unsigned int id);
+void 	 gog_object_register_roles	  (GogObjectClass *klass,
+					   GogObjectRole const *roles, unsigned n_roles);
+void 	 gog_object_request_editor_update (GogObject *obj);
 
 G_END_DECLS
 
