@@ -20,27 +20,18 @@
 #include <goffice/goffice-config.h>
 #include "go-format-sel.h"
 
-#include <goffice/gtk/goffice-gtk.h>
-#include <goffice/gtk/go-combo-text.h>
-#include <goffice/utils/format-impl.h>
-#include <goffice/utils/go-color.h>
-#include <goffice/utils/go-marshalers.h>
+#include "goffice/gtk/goffice-gtk.h"
+#include "goffice/gtk/go-combo-text.h"
+#include "goffice/utils/go-format.h"
+#include "goffice/utils/go-locale.h"
+#include "goffice/utils/go-color.h"
+#include "goffice/utils/go-marshalers.h"
 
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtksizegroup.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtktextview.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtktreeview.h>
+#include <gtk/gtk.h>
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
 
 #include <string.h>
-#include <locale.h>
 
 /* The maximum number of chars in the formatting sample */
 #define FORMAT_PREVIEW_MAX 25
@@ -106,10 +97,10 @@ typedef enum {
 	F_ENTRY,
 	F_LIST_LABEL,		F_LIST_SCROLL,		F_LIST,
 	F_DECIMAL_SPIN,		F_ENGINEERING_BUTTON,	
-	F_SUPERSCRIPT_BOX,	F_SUPERSCRIPT_BUTTON,	F_SUPERSCRIPT_HIDE_1_BUTTON,
+	F_SUPERSCRIPT_BUTTON,	F_SUPERSCRIPT_HIDE_1_BUTTON,
 	F_NEGATIVE_LABEL,	F_NEGATIVE_SCROLL,	F_NEGATIVE,
-	F_DECIMAL_LABEL,	F_CODE_LABEL,	F_SYMBOL_BOX,
-	F_DECIMAL_BOX,	F_CODE_BOX,	F_MAX_WIDGET
+	F_DECIMAL_LABEL,	F_CODE_LABEL,
+	F_MAX_WIDGET
 } FormatWidget;
 
 struct  _GOFormatSel {
@@ -187,7 +178,7 @@ generate_format (GOFormatSel *gfs)
 	 * It is a strange idea not to reuse GOFormatDetails
 	 * in this file, so build one.
 	 */
-	GOFormatDetails format = gfs->format.spec->family_info;
+	GOFormatDetails format = *go_format_get_details (gfs->format.spec);
 	format.thousands_sep = gfs->format.use_separator;
 	format.num_decimals = gfs->format.num_decimals;
 	format.negative_fmt = gfs->format.negative_format;
@@ -274,11 +265,11 @@ fillin_negative_samples (GOFormatSel *gfs)
 	START_LOCALE_SWITCH;
 
 	if (gfs->format.use_separator)
-		thousand_sep = go_format_get_thousand ()->str;
+		thousand_sep = go_locale_get_thousand ()->str;
 	else
 		thousand_sep = "";
 	if (gfs->format.num_decimals > 0)
-		decimal = go_format_get_decimal ()->str;
+		decimal = go_locale_get_decimal ()->str;
 	else
 		decimal = "";
 
@@ -403,7 +394,7 @@ fmt_dialog_init_fmt_list (GOFormatSel *gfs, char const *const *formats,
 {
 	GtkTreeIter iter;
 	char *fmt;
-	char const *cur_fmt = gfs->format.spec->format;
+	char *cur_fmt = go_format_as_XL (gfs->format.spec, FALSE);
 
 	for (; *formats; formats++) {
 		gtk_list_store_append (gfs->format.formats.model, &iter);
@@ -415,6 +406,8 @@ fmt_dialog_init_fmt_list (GOFormatSel *gfs, char const *const *formats,
 		if (!strcmp (*formats, cur_fmt))
 			*select = iter;
 	}
+
+	g_free (cur_fmt);
 }
 
 static void
@@ -430,7 +423,6 @@ fmt_dialog_enable_widgets (GOFormatSel *gfs, int page)
 		/* Number */
 		{
 			F_NUMBER_EXPLANATION,
-			F_DECIMAL_BOX,
 			F_DECIMAL_LABEL,
 			F_DECIMAL_SPIN,
 			F_SEPARATOR,
@@ -442,11 +434,9 @@ fmt_dialog_enable_widgets (GOFormatSel *gfs, int page)
 		/* Currency */
 		{
 			F_CURRENCY_EXPLANATION,
-			F_DECIMAL_BOX,
 			F_DECIMAL_LABEL,
 			F_DECIMAL_SPIN,
 			F_SEPARATOR,
-			F_SYMBOL_BOX,
 			F_SYMBOL_LABEL,
 			F_SYMBOL,
 			F_NEGATIVE_LABEL,
@@ -457,10 +447,8 @@ fmt_dialog_enable_widgets (GOFormatSel *gfs, int page)
 		/* Accounting */
 		{
 			F_ACCOUNTING_EXPLANATION,
-			F_DECIMAL_BOX,
 			F_DECIMAL_LABEL,
 			F_DECIMAL_SPIN,
-			F_SYMBOL_BOX,
 			F_SYMBOL_LABEL,
 			F_SYMBOL,
 			F_MAX_WIDGET
@@ -484,7 +472,6 @@ fmt_dialog_enable_widgets (GOFormatSel *gfs, int page)
 		/* Percentage */
 		{
 			F_PERCENTAGE_EXPLANATION,
-			F_DECIMAL_BOX,
 			F_DECIMAL_LABEL,
 			F_DECIMAL_SPIN,
 			F_MAX_WIDGET
@@ -500,11 +487,9 @@ fmt_dialog_enable_widgets (GOFormatSel *gfs, int page)
 		/* Scientific */
 		{
 			F_SCIENTIFIC_EXPLANATION,
-			F_DECIMAL_BOX,
 			F_DECIMAL_LABEL,
 			F_DECIMAL_SPIN,
 			F_ENGINEERING_BUTTON,
-			F_SUPERSCRIPT_BOX,
 			F_SUPERSCRIPT_BUTTON,
 			F_SUPERSCRIPT_HIDE_1_BUTTON,
 			F_MAX_WIDGET
@@ -522,7 +507,6 @@ fmt_dialog_enable_widgets (GOFormatSel *gfs, int page)
 		/* Custom */
 		{
 			F_CUSTOM_EXPLANATION,
-			F_CODE_BOX,
 			F_CODE_LABEL,
 			F_ENTRY,
 			F_LIST_LABEL,
@@ -559,8 +543,8 @@ stays:
 	    page == GO_FORMAT_TEXT) {
 		int list_elem = 0;
 		char *tmp;
-		if (page == gfs->format.spec->family)
-			list_elem = gfs->format.spec->family_info.list_element;
+		if (page == go_format_get_family (gfs->format.spec))
+			list_elem = go_format_get_details (gfs->format.spec)->list_element;
 
 		tmp = go_format_str_as_XL (go_format_builtins[page][list_elem], TRUE);
 		format_entry_set_text (gfs, tmp);
@@ -635,11 +619,6 @@ stays:
 						   gfs->format.num_decimals);
 			break;
 
-		case F_SUPERSCRIPT_BOX:
-			if (!gfs->show_format_with_markup)
-				show_widget = FALSE;
-			break;
-
 		case F_SUPERSCRIPT_BUTTON:
 			if (gfs->show_format_with_markup) {
 				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w),
@@ -673,8 +652,12 @@ stays:
 			; /* Nothing */
 		}
 
-		if (show_widget)
-			gtk_widget_show (w);
+		if (show_widget) {
+			while (!GTK_WIDGET_VISIBLE (w)) {
+				gtk_widget_show (w);
+				w = w->parent;
+			}
+		}
 	}
 
 	draw_format_preview (gfs, TRUE);
@@ -715,11 +698,14 @@ static void
 cb_format_entry_changed (GtkEditable *w, GOFormatSel *gfs)
 {
 	char *fmt;
+	char *cur_fmt;
 	if (!gfs->enable_edit)
 		return;
 
 	fmt = go_format_str_delocalize (gtk_entry_get_text (GTK_ENTRY (w)));
-	if (strcmp (gfs->format.spec->format, fmt)) {
+	cur_fmt = go_format_as_XL (gfs->format.spec, FALSE);
+
+	if (strcmp (cur_fmt, fmt)) {
 		go_format_unref (gfs->format.spec);
 		gfs->format.spec = go_format_new_from_XL (fmt, FALSE);
 		g_signal_emit (G_OBJECT (gfs),
@@ -727,7 +713,9 @@ cb_format_entry_changed (GtkEditable *w, GOFormatSel *gfs)
 			       fmt);
 		draw_format_preview (gfs, FALSE);
 	}
+
 	g_free (fmt);
+	g_free (cur_fmt);
 }
 
 /*
@@ -849,7 +837,8 @@ set_format_category_menu_from_style (GOFormatSel *gfs)
 	g_return_if_fail (IS_GO_FORMAT_SEL (gfs));
 
 	/* Attempt to extract general parameters from the current format */
-	if ((page = gfs->format.spec->family) < 0)
+	page = go_format_get_family (gfs->format.spec);
+	if (page < 0)
 		page = FMT_CUSTOM; /* Default to custom */
 
 	set_format_category (gfs, page);
@@ -925,7 +914,6 @@ nfs_init (GOFormatSel *gfs)
 		"format_list",
 		"format_number_decimals",
 		"format_engineering_button",
-		"format_superscript_box",
 		"format_superscript_button",
 		"format_superscript_hide_1_button",
 		"format_negatives_label",
@@ -933,9 +921,6 @@ nfs_init (GOFormatSel *gfs)
 		"format_negatives",
 		"format_decimal_label",
 		"format_code_label",
-		"format_symbol_box",
-		"format_decimal_box",
-		"format_code_box",
 		NULL
 	};
 
@@ -945,6 +930,7 @@ nfs_init (GOFormatSel *gfs)
 	char const *name;
 	int i;
 	GOFormatFamily page;
+	const GOFormatDetails *family_info;
 
 	GtkWidget *toplevel;
 	GtkWidget *old_parent;
@@ -973,10 +959,11 @@ nfs_init (GOFormatSel *gfs)
 	gfs->format.current_type = -1;
 
 	/* Even if the format was not recognized it has set intelligent defaults */
-	gfs->format.use_separator = gfs->format.spec->family_info.thousands_sep;
-	gfs->format.num_decimals = gfs->format.spec->family_info.num_decimals;
-	gfs->format.negative_format = gfs->format.spec->family_info.negative_fmt;
-	gfs->format.currency_index = gfs->format.spec->family_info.currency_symbol_index;
+	family_info = go_format_get_details (gfs->format.spec);
+	gfs->format.use_separator = family_info->thousands_sep;
+	gfs->format.num_decimals = family_info->num_decimals;
+	gfs->format.negative_format = family_info->negative_fmt;
+	gfs->format.currency_index = family_info->currency_symbol_index;
 	
 	gfs->format.use_markup = FALSE;
 	gfs->format.simplify_mantissa = FALSE;
@@ -1110,7 +1097,8 @@ nfs_init (GOFormatSel *gfs)
 	/* Connect signal for format menu */
 	set_format_category_menu_from_style (gfs);
 
-	if ((page = gfs->format.spec->family) < 0)
+	page = go_format_get_family (gfs->format.spec);
+	if (page < 0)
 		page = FMT_CUSTOM; /* Default to custom */
 	fmt_dialog_enable_widgets (gfs, page);
 
@@ -1238,6 +1226,7 @@ go_format_sel_set_style_format (GOFormatSel *gfs,
 				GOFormat *style_format)
 {
 	GoComboText *combo;
+	const GOFormatDetails *family_info;
 
 	g_return_if_fail (IS_GO_FORMAT_SEL (gfs));
 	g_return_if_fail (style_format != NULL);
@@ -1248,13 +1237,14 @@ go_format_sel_set_style_format (GOFormatSel *gfs,
 
 	gfs->format.spec = style_format;
 
-	gfs->format.use_separator 	= style_format->family_info.thousands_sep;
-	gfs->format.num_decimals 	= style_format->family_info.num_decimals;
-	gfs->format.negative_format 	= style_format->family_info.negative_fmt;
-	gfs->format.currency_index 	= style_format->family_info.currency_symbol_index;
-	gfs->format.use_markup 		= style_format->family_info.use_markup;
-	gfs->format.exponent_step	= style_format->family_info.exponent_step;
-	gfs->format.simplify_mantissa	= style_format->family_info.simplify_mantissa;
+	family_info = go_format_get_details (style_format);
+	gfs->format.use_separator 	= family_info->thousands_sep;
+	gfs->format.num_decimals 	= family_info->num_decimals;
+	gfs->format.negative_format 	= family_info->negative_fmt;
+	gfs->format.currency_index 	= family_info->currency_symbol_index;
+	gfs->format.use_markup 		= family_info->use_markup;
+	gfs->format.exponent_step	= family_info->exponent_step;
+	gfs->format.simplify_mantissa	= family_info->simplify_mantissa;
 
 	combo = GO_COMBO_TEXT (gfs->format.widget[F_SYMBOL]);
 	go_combo_text_set_text
@@ -1333,7 +1323,7 @@ go_format_sel_set_locale (GOFormatSel *gfs,
 char const *    
 go_format_sel_format_classification (GOFormat const *style_format)
 {
-	GOFormatFamily page = style_format->family;
+	GOFormatFamily page = go_format_get_family (style_format);
 
 	if (page < 0 || page > FMT_CUSTOM)
 		page = FMT_CUSTOM; /* Default to custom */
