@@ -10,6 +10,7 @@
  */
 #include <goffice/goffice-config.h>
 #include "go-format.h"
+#include "go-locale.h"
 #include <goffice/utils/regutf8.h>
 #include <glib/gi18n-lib.h>
 #include <string.h>
@@ -189,7 +190,7 @@ void
 go_currency_date_format_init (void)
 {
 	gboolean precedes, space_sep;
-	char const *curr = format_get_currency (&precedes, &space_sep)->str;
+	char const *curr = go_locale_get_currency (&precedes, &space_sep)->str;
 	char *pre, *post, *pre_rep, *post_rep;
 	int err;
 
@@ -299,7 +300,7 @@ go_currency_date_format_init (void)
 
 	g_free (*pre ? pre : post);
 
-	if (!format_month_before_day ()) {
+	if (!go_locale_month_before_day ()) {
 		fmts_date [0]  = "d/m/yy";
 		fmts_date [1]  = "d/m/yyyy";
 		fmts_date [2]  = "mmm-d-yy";
@@ -572,7 +573,11 @@ find_currency (char const *ptr, int len)
 {
 	int i;
 
-	if (len == 5 && memcmp (ptr, "\"€\"", 5) == 0) {
+	/* the below string is actually "\"€\"". We use hex codes
+	 * here because Micrsoft's C compiler will parse this string
+	 * incorrectly if the environment multiple-byte encoding is NOT
+	 * iso-8859-1 compatible. See also find_decimal_char() in format.c */
+	if (len == 5 && memcmp (ptr, "\"\xe2\x82\xac\"", 5) == 0) {
 		/* Accept quoted Euro character -- arbitrarity pick form 1.  */
 		return EURO_FORM_1;
 	} else if (len >= 2 && ptr[0] == '"' && ptr [len - 1] == '"') {
@@ -739,46 +744,76 @@ cell_format_is_fraction (char const *fmt, GOFormatDetails *info)
 	return TRUE;
 }
 
+static gboolean
+cell_format_is_time (char const *fmt, GOFormatDetails *info)
+{
+	if (strstr (fmt, "[h]") || strstr (fmt, "hh") ||
+	    strstr (fmt, "mm:ss"))
+		return TRUE;
+
+	return FALSE;
+}
+
+static gboolean
+cell_format_is_date (char const *fmt, GOFormatDetails *info)
+{
+	if (strstr (fmt, "yy") || strstr (fmt, "mmm")) {
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
 
 GOFormatFamily
 go_format_classify (GOFormat const *gf, GOFormatDetails *info)
 {
-	char const *fmt = gf->format;
+	char *fmt;
 	GOFormatFamily res;
 	int i;
 
-	g_return_val_if_fail (fmt != NULL, GO_FORMAT_GENERAL);
+	g_return_val_if_fail (gf != NULL, GO_FORMAT_GENERAL);
 	g_return_val_if_fail (info != NULL, GO_FORMAT_GENERAL);
 
+	fmt = go_format_as_XL (gf, FALSE);
+
 	/* Init the result to something sane */
 	info->thousands_sep = FALSE;
 	info->num_decimals = 2;
 	info->negative_fmt = 0;
 	info->list_element = 0;
 	info->currency_symbol_index = 1; /* '$' */
-	info->date_has_days = FALSE;
-	info->date_has_months = FALSE;
 	info->fraction_denominator = 0;
 	info->use_markup = FALSE;
 	info->exponent_step = 1;
 	info->simplify_mantissa = FALSE;
 
-	if (*fmt == '\0')
+	if (*fmt == '\0') {
+		g_free (fmt);
 		return GO_FORMAT_UNKNOWN;
+	}
 
 	/* Note: ->family is not yet ready.  */
-	if (g_ascii_strcasecmp (gf->format, fmts_general[0]) == 0)
+	if (g_ascii_strcasecmp (fmt, fmts_general[0]) == 0) {
+		g_free (fmt);
 		return GO_FORMAT_GENERAL;
+	}
 
-	if (fmt[0] == '@' && fmt[1] == '[')
+	if (fmt[0] == '@' && fmt[1] == '[') {
+		g_free (fmt);
 		return GO_FORMAT_MARKUP;
+	}
 
 	/* Can we parse it ? */
-	if ((res = cell_format_is_number (fmt, info)) != GO_FORMAT_UNKNOWN)
+	if ((res = cell_format_is_number (fmt, info)) != GO_FORMAT_UNKNOWN) {
+		g_free (fmt);
 		return res;
+	}
 
-	if (cell_format_is_fraction (fmt, info))
+	if (cell_format_is_fraction (fmt, info)) {
+		g_free (fmt);
 		return GO_FORMAT_FRACTION;
+	}
 
 	/* Is it in the lists */
 	for (i = 0; go_format_builtins[i] != NULL ; ++i) {
@@ -787,19 +822,21 @@ go_format_classify (GOFormat const *gf, GOFormatDetails *info)
 		for (; elem[j] ; ++j)
 			if (g_ascii_strcasecmp (_(elem[j]), fmt) == 0) {
 				info->list_element = j;
-				switch (i) {
-				case GO_FORMAT_DATE:
-					info->date_has_days = 
-						(NULL != g_utf8_strchr (elem[j],-1,'d'));
-					info->date_has_months = 
-						(NULL != g_utf8_strchr (elem[j],-1,'m'));
-					break;
-				default:
-					break;
-				}
-				
+				g_free (fmt);
 				return i;
 			}
 	}
+
+	if (cell_format_is_time (fmt, info)) {
+		g_free (fmt);
+		return GO_FORMAT_TIME;
+	}
+
+	if (cell_format_is_date (fmt, info)) {
+		g_free (fmt);
+		return GO_FORMAT_DATE;
+	}
+
+	g_free (fmt);
 	return GO_FORMAT_UNKNOWN;
 }
