@@ -25,8 +25,7 @@
 #include <goffice/utils/go-math.h>
 
 #ifdef GOFFICE_WITH_GTK
-#include <goffice/gtk/go-combo-color.h>
-#include <goffice/gtk/go-combo-pixmaps.h>
+#include <goffice/gtk/go-palette.h>
 #include <gdk-pixbuf/gdk-pixdata.h>
 #include <glade/glade-xml.h>
 #endif
@@ -257,17 +256,6 @@ static MarkerShape const marker_shapes[GO_MARKER_MAX] = {
 static GObjectClass *marker_parent_klass;
 
 #ifdef GOFFICE_WITH_GTK
-static GdkPixbuf *
-new_blank_pixbuf (GOMarker *marker, guint size)
-{
-	int offset = ceil ((double)size * MARKER_OUTLINE_WIDTH / 2.0);
-	int pixbuf_size = size + 1 + 2 * offset;
-	GdkPixbuf *res = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8,
-					    pixbuf_size, pixbuf_size);
-	gdk_pixbuf_fill (res, 0); /* in case the fill colours have alpha = 0 */
-	return res;
-}
-
 static GdkPixbuf *
 marker_create_pixbuf_with_size (GOMarker *marker, guint size)
 {
@@ -281,14 +269,13 @@ marker_create_pixbuf_with_size (GOMarker *marker, guint size)
 	ArtVpath  *fill_path;
 	GdkPixbuf *pixbuf;
 
-	size = rint (marker->scale * size);
+	size = go_rint (marker->scale * size);
 
 	if (size < 1 || marker->shape == GO_MARKER_NONE)
 		return NULL;
 
 	/* FIXME : markers look bad due to grey outline */
 
-	/* keep in sync with new_blank_pixbuf */
 	offset = ceil ((double)size * MARKER_OUTLINE_WIDTH / 2.0);
 	pixbuf_size = size + 1 + 2 * offset;
 	half_size = (double)size / 2.0;
@@ -347,6 +334,8 @@ marker_free_pixbuf (GOMarker * marker)
 static void
 marker_update_pixbuf (GOMarker * marker)
 {
+	if (marker->pixbuf)
+		marker_free_pixbuf (marker);
 	marker->pixbuf = marker_create_pixbuf_with_size (marker, marker->size);
 }
 #else
@@ -399,7 +388,7 @@ go_marker_shape_as_str (GOMarkerShape shape)
 }
 
 void
-go_marker_get_paths (GOMarker * marker,
+go_marker_get_paths (GOMarker const *marker,
 		     ArtVpath const **outline_path,
 		     ArtVpath const **fill_path)
 {
@@ -431,7 +420,7 @@ go_marker_get_pixbuf_with_size (GOMarker *marker, guint size)
 #endif /* GOFFICE_WITH_GTK */
 
 GOMarkerShape 
-go_marker_get_shape (GOMarker * marker)
+go_marker_get_shape (GOMarker const *marker)
 {
 	return marker->shape;
 }
@@ -447,7 +436,7 @@ go_marker_set_shape (GOMarker *marker, GOMarkerShape shape)
 }
 	
 GOColor
-go_marker_get_outline_color (GOMarker * marker)
+go_marker_get_outline_color (GOMarker const *marker)
 {
 	return marker->outline_color;
 }
@@ -463,7 +452,7 @@ go_marker_set_outline_color (GOMarker *marker, GOColor color)
 }
 	
 GOColor
-go_marker_get_fill_color (GOMarker * marker)
+go_marker_get_fill_color (GOMarker const *marker)
 {
 	return marker->fill_color;
 }
@@ -479,13 +468,13 @@ go_marker_set_fill_color (GOMarker *marker, GOColor color)
 }
 	
 int
-go_marker_get_size (GOMarker * marker)
+go_marker_get_size (GOMarker const *marker)
 {
 	return marker->size;
 }
 
 double 
-go_marker_get_outline_width (GOMarker * marker)
+go_marker_get_outline_width (GOMarker const *marker)
 {
 	return (double)marker->size * MARKER_OUTLINE_WIDTH;
 }
@@ -517,7 +506,7 @@ go_marker_assign (GOMarker *dst, GOMarker const *src)
 
 #ifdef GOFFICE_WITH_GTK
 	if (dst->pixbuf != NULL)
-		g_object_unref (src->pixbuf);
+		g_object_unref (dst->pixbuf);
 	dst->pixbuf = src->pixbuf;
 	if (dst->pixbuf != NULL)
 		g_object_ref (dst->pixbuf);
@@ -525,7 +514,7 @@ go_marker_assign (GOMarker *dst, GOMarker const *src)
 }	
 	
 GOMarker *
-go_marker_dup (GOMarker *src)
+go_marker_dup (GOMarker const *src)
 {
 	GOMarker *dst = go_marker_new ();
 	go_marker_assign (dst, src);
@@ -541,56 +530,3 @@ go_marker_new (void)
 GSF_CLASS (GOMarker, go_marker,
 	   go_marker_class_init, go_marker_init,
 	   G_TYPE_OBJECT)
-
-/*---------------------------------------------------------------------------*/
-
-#ifdef GOFFICE_WITH_GTK
-gpointer
-go_marker_selector (GOColor outline_color, GOColor fill_color,
-		    GOMarkerShape default_shape)
-{
-	static const GOMarkerShape elements[] = {
-		GO_MARKER_NONE,		GO_MARKER_TRIANGLE_UP,	GO_MARKER_BUTTERFLY,
-		GO_MARKER_TRIANGLE_LEFT, GO_MARKER_DIAMOND,	GO_MARKER_TRIANGLE_RIGHT,
-		GO_MARKER_BAR,		GO_MARKER_TRIANGLE_DOWN, GO_MARKER_HOURGLASS,
-		GO_MARKER_HALF_BAR,	GO_MARKER_SQUARE,	GO_MARKER_CIRCLE,
-		GO_MARKER_X,		GO_MARKER_CROSS,	GO_MARKER_ASTERISK,
-		GO_MARKER_MAX /* fill with auto */
-	};
-
-	unsigned	 i;
-	GOComboPixmaps	*w;
-	GOMarker	*marker = go_marker_new ();
-
-	go_marker_set_fill_color (marker, fill_color);
-	go_marker_set_outline_color (marker, outline_color);
-	go_marker_set_size (marker, 15);
-
-	w = go_combo_pixmaps_new (4);
-	for (i = 0; i < G_N_ELEMENTS (elements); i++) {
-		GOMarkerShape shape = elements[i];
-		gboolean is_auto = (shape == GO_MARKER_MAX);
-		GdkPixbuf *pixbuf;
-
-		go_marker_set_shape (marker, is_auto ? default_shape : shape);
-		pixbuf = go_marker_get_pixbuf (marker, 1.0);
-		if (pixbuf == NULL) /* handle none */
-			pixbuf = new_blank_pixbuf (marker, marker->size);
-		else	/* add_element absorbs ref */
-			g_object_ref (pixbuf);
-		if (is_auto) {
-			/* xgettext : this will appear as 'Automatic (shapename)' */
-			char *name = g_strdup_printf (_("Automatic (%s)"),
-				_(marker_shapes [default_shape].name));
-			go_combo_pixmaps_add_element (w, pixbuf,
-				-default_shape, name);
-			g_free (name);
-		} else
-			go_combo_pixmaps_add_element (w, pixbuf,
-				shape, _(marker_shapes [shape].name));
-	}
-	g_object_unref (marker);
-
-	return GTK_WIDGET (w);
-}
-#endif /* GOFFICE_WITH_GTK */
