@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -23,10 +23,11 @@
 #define GO_MARKER_H
 
 #include <glib-object.h>
+#include <goffice/goffice-features.h>
 #include <goffice/utils/goffice-utils.h>
 #include <libart_lgpl/art_vpath.h>
 
-#ifdef WITH_GTK
+#ifdef GOFFICE_WITH_GTK
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #endif
 
@@ -55,52 +56,30 @@ typedef enum {
 	GO_MARKER_MAX
 } GOMarkerShape;
 
-struct _GOMarker {
-	GObject 	base;
-
-	int		size;
-	double		scale;
-	GOMarkerShape	shape;
-	GOColor		outline_color;
-	GOColor		fill_color;
-#ifdef WITH_GTK
-	GdkPixbuf	*pixbuf;
-#else
-	gpointer	 pixbuf_placeholder;
-#endif
-};
-
 GType go_marker_get_type (void); 
 
-
 GOMarkerShape    go_marker_shape_from_str       (char const *name);
 char const      *go_marker_shape_as_str         (GOMarkerShape shape);
-void		 go_marker_get_paths		(GOMarker * marker,
+void		 go_marker_get_paths		(GOMarker const *marker,
 						 ArtVpath const **outline_path,
 						 ArtVpath const **fill_path);
-GOMarkerShape 	 go_marker_get_shape		(GOMarker *m);
+GOMarkerShape 	 go_marker_get_shape		(GOMarker const *m);
 void 		 go_marker_set_shape 		(GOMarker *m, GOMarkerShape shape);
-GOColor 	 go_marker_get_outline_color	(GOMarker *m);
+GOColor 	 go_marker_get_outline_color	(GOMarker const *m);
 void		 go_marker_set_outline_color	(GOMarker *m, GOColor color);
-GOColor		 go_marker_get_fill_color	(GOMarker *m);
+GOColor		 go_marker_get_fill_color	(GOMarker const *m);
 void		 go_marker_set_fill_color	(GOMarker *m, GOColor color);
-int		 go_marker_get_size		(GOMarker *m);
+int		 go_marker_get_size		(GOMarker const *m);
 void		 go_marker_set_size		(GOMarker *m, int size);
-double		 go_marker_get_outline_width	(GOMarker *m);
+double		 go_marker_get_outline_width	(GOMarker const *m);
 
 void		 go_marker_assign 		(GOMarker *dst, GOMarker const *src);
-GOMarker *	 go_marker_dup 			(GOMarker *src);
+GOMarker *	 go_marker_dup 			(GOMarker const *src);
 GOMarker * 	 go_marker_new 			(void);
 
-#ifdef WITH_GTK
+#ifdef GOFFICE_WITH_GTK
 GdkPixbuf       *go_marker_get_pixbuf		(GOMarker *m, double scale);
 GdkPixbuf       *go_marker_get_pixbuf_with_size (GOMarker *m, guint size);
-
-gpointer 	 go_marker_selector 		(GOColor outline_color, 
-						 GOColor fill_color,
-						 GOMarkerShape default_shape);
-GOMarkerShape	 go_marker_selector_get_shape	(gpointer selector,
-						 int index, gboolean *is_auto);
 #endif
 	
 G_END_DECLS
